==> eiffelstudio-18.11.10.2592.tar: F_code/C5/ba220.c <==
/*
 * Code for class BASE64
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ba220.h"
#include "eif_built_in.h"
#include "eif_misc.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {BASE64}.has_error */
EIF_BOOLEAN F255_3613 (EIF_REFERENCE Current)
{
	return *(EIF_BOOLEAN *)(Current+ _CHROFF_0_0_);
}


/* {BASE64}.encoded_string */
EIF_REFERENCE F255_3615 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_CHARACTER_8 tc1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTCFDT;
	RTLD;
	
	RTLI(6);
	RTLR(0,Current);
	RTLR(1,loc5);
	RTLR(2,arg1);
	RTLR(3,loc4);
	RTLR(4,tr1);
	RTLR(5,Result);
	RTLIU(6);
	
	RTGC;
	*(EIF_BOOLEAN *)(Current+ _CHROFF_0_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	loc5 = RTOUCR(723,F255_3621,(Current));
	loc2 = *(EIF_INTEGER_32 *)(RTCW(arg1) + O8415[Dtype(arg1)-1129]);
	loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (((EIF_INTEGER_32) 8L) * loc2) % ((EIF_INTEGER_32) 6L));
	if ((EIF_BOOLEAN) (loc1 > ((EIF_INTEGER_32) 0L))) {
		{
			static EIF_TYPE_INDEX typarr0[] = {0xFF01,1209,1083,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
			tr1 = RTLNSP2(typres0.id,0,(EIF_INTEGER_32) ((EIF_INTEGER_32) (((EIF_INTEGER_32) 8L) * loc2) + (EIF_INTEGER_32) (((EIF_INTEGER_32) 6L) - loc1)),sizeof(EIF_BOOLEAN), EIF_TRUE);
		}
		F1210_10664(RTCW(tr1), (EIF_BOOLEAN) 0, (EIF_INTEGER_32) ((EIF_INTEGER_32) (((EIF_INTEGER_32) 8L) * loc2) + (EIF_INTEGER_32) (((EIF_INTEGER_32) 6L) - loc1)));
		loc4 = (EIF_REFERENCE) tr1;
	} else {
		{
			static EIF_TYPE_INDEX typarr0[] = {0xFF01,1209,1083,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
			tr1 = RTLNSP2(typres0.id,0,(EIF_INTEGER_32) (((EIF_INTEGER_32) 8L) * loc2),sizeof(EIF_BOOLEAN), EIF_TRUE);
		}
		F1210_10664(RTCW(tr1), (EIF_BOOLEAN) 0, (EIF_INTEGER_32) (((EIF_INTEGER_32) 8L) * loc2));
		loc4 = (EIF_REFERENCE) tr1;
	}
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	for (;;) {
		if ((EIF_BOOLEAN) (loc1 > (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 1L)))) break;
		tc1 = *(EIF_CHARACTER_8 *)(eif_optimize_return = 1, (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R7069[Dtype(arg1)-905])(RTCW(arg1), (EIF_INTEGER_32) (loc1 + ((EIF_INTEGER_32) 1L))));
		loc3 = (EIF_INTEGER_32) (tc1);
		tb1 = eif_bit_test(EIF_INTEGER_32,loc3,((EIF_INTEGER_32) 7L));
		/* INLINED CODE (SPECIAL.put) */
		*((EIF_BOOLEAN *)RTCW(loc4) + ((EIF_INTEGER_32) ((EIF_INTEGER_32) (((EIF_INTEGER_32) 8L) * loc1) + ((EIF_INTEGER_32) 0L)))) = tb1;
		/* END INLINED CODE */
		;
		tb1 = eif_bit_test(EIF_INTEGER_32,loc3,((EIF_INTEGER_32) 6L));
		/* INLINED CODE (SPECIAL.put) */
		*((EIF_BOOLEAN *)RTCW(loc4) + ((EIF_INTEGER_32) ((EIF_INTEGER_32) (((EIF_INTEGER_32) 8L) * loc1) + ((EIF_INTEGER_32) 1L)))) = tb1;
		/* END INLINED CODE */
		;
		tb1 = eif_bit_test(EIF_INTEGER_32,loc3,((EIF_INTEGER_32) 5L));
		/* INLINED CODE (SPECIAL.put) */
		*((EIF_BOOLEAN *)RTCW(loc4) + ((EIF_INTEGER_32) ((EIF_INTEGER_32) (((EIF_INTEGER_32) 8L) * loc1) + ((EIF_INTEGER_32) 2L)))) = tb1;
		/* END INLINED CODE */
		;
		tb1 = eif_bit_test(EIF_INTEGER_32,loc3,((EIF_INTEGER_32) 4L));
		/* INLINED CODE (SPECIAL.put) */
		*((EIF_BOOLEAN *)RTCW(loc4) + ((EIF_INTEGER_32) ((EIF_INTEGER_32) (((EIF_INTEGER_32) 8L) * loc1) + ((EIF_INTEGER_32) 3L)))) = tb1;
		/* END INLINED CODE */
		;
		tb1 = eif_bit_test(EIF_INTEGER_32,loc3,((EIF_INTEGER_32) 3L));
		/* INLINED CODE (SPECIAL.put) */
		*((EIF_BOOLEAN *)RTCW(loc4) + ((EIF_INTEGER_32) ((EIF_INTEGER_32) (((EIF_INTEGER_32) 8L) * loc1) + ((EIF_INTEGER_32) 4L)))) = tb1;
		/* END INLINED CODE */
		;
		tb1 = eif_bit_test(EIF_INTEGER_32,loc3,((EIF_INTEGER_32) 2L));
		/* INLINED CODE (SPECIAL.put) */
		*((EIF_BOOLEAN *)RTCW(loc4) + ((EIF_INTEGER_32) ((EIF_INTEGER_32) (((EIF_INTEGER_32) 8L) * loc1) + ((EIF_INTEGER_32) 5L)))) = tb1;
		/* END INLINED CODE */
		;
		tb1 = eif_bit_test(EIF_INTEGER_32,loc3,((EIF_INTEGER_32) 1L));
		/* INLINED CODE (SPECIAL.put) */
		*((EIF_BOOLEAN *)RTCW(loc4) + ((EIF_INTEGER_32) ((EIF_INTEGER_32) (((EIF_INTEGER_32) 8L) * loc1) + ((EIF_INTEGER_32) 6L)))) = tb1;
		/* END INLINED CODE */
		;
		tb1 = eif_bit_test(EIF_INTEGER_32,loc3,((EIF_INTEGER_32) 0L));
		/* INLINED CODE (SPECIAL.put) */
		*((EIF_BOOLEAN *)RTCW(loc4) + ((EIF_INTEGER_32) ((EIF_INTEGER_32) (((EIF_INTEGER_32) 8L) * loc1) + ((EIF_INTEGER_32) 7L)))) = tb1;
		/* END INLINED CODE */
		;
		loc1++;
	}
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	loc2 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (loc4);
	tr1 = RTLNS(eif_new_type(1131, 0x01).id, 1131, _OBJSIZ_1_1_0_3_0_0_0_0_);
	F1130_9883(RTCW(tr1), (EIF_INTEGER_32) (loc2 / ((EIF_INTEGER_32) 6L)));
	Result = (EIF_REFERENCE) tr1;
	for (;;) {
		if ((EIF_BOOLEAN) (loc1 > (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 1L)))) break;
		loc3 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
		/* INLINED CODE (SPECIAL.item) */
		tb2 = *((EIF_BOOLEAN *)RTCW(loc4) + ((EIF_INTEGER_32) (loc1 + ((EIF_INTEGER_32) 0L))));
		/* END INLINED CODE */
		tb1 = tb2;
		if (tb1) {
			loc3 += ((EIF_INTEGER_32) 32L);
		}
		/* INLINED CODE (SPECIAL.item) */
		tb2 = *((EIF_BOOLEAN *)RTCW(loc4) + ((EIF_INTEGER_32) (loc1 + ((EIF_INTEGER_32) 1L))));
		/* END INLINED CODE */
		tb1 = tb2;
		if (tb1) {
			loc3 += ((EIF_INTEGER_32) 16L);
		}
		/* INLINED CODE (SPECIAL.item) */
		tb2 = *((EIF_BOOLEAN *)RTCW(loc4) + ((EIF_INTEGER_32) (loc1 + ((EIF_INTEGER_32) 2L))));
		/* END INLINED CODE */
		tb1 = tb2;
		if (tb1) {
			loc3 += ((EIF_INTEGER_32) 8L);
		}
		/* INLINED CODE (SPECIAL.item) */
		tb2 = *((EIF_BOOLEAN *)RTCW(loc4) + ((EIF_INTEGER_32) (loc1 + ((EIF_INTEGER_32) 3L))));
		/* END INLINED CODE */
		tb1 = tb2;
		if (tb1) {
			loc3 += ((EIF_INTEGER_32) 4L);
		}
		/* INLINED CODE (SPECIAL.item) */
		tb2 = *((EIF_BOOLEAN *)RTCW(loc4) + ((EIF_INTEGER_32) (loc1 + ((EIF_INTEGER_32) 4L))));
		/* END INLINED CODE */
		tb1 = tb2;
		if (tb1) {
			loc3 += ((EIF_INTEGER_32) 2L);
		}
		/* INLINED CODE (SPECIAL.item) */
		tb2 = *((EIF_BOOLEAN *)RTCW(loc4) + ((EIF_INTEGER_32) (loc1 + ((EIF_INTEGER_32) 5L))));
		/* END INLINED CODE */
		tb1 = tb2;
		if (tb1) {
			loc3++;
		}
		tc1 = *(EIF_CHARACTER_8 *)(eif_optimize_return = 1, (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R7069[Dtype(loc5)-905])(RTCW(loc5), (EIF_INTEGER_32) (loc3 + ((EIF_INTEGER_32) 1L))));
		F1132_10009(RTCW(Result), tc1);
		loc1 += ((EIF_INTEGER_32) 6L);
	}
	loc1 = *(EIF_INTEGER_32 *)(RTCW(arg1) + O8415[Dtype(arg1)-1129]);
	loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc1 % ((EIF_INTEGER_32) 3L));
	if ((EIF_BOOLEAN) (loc1 > ((EIF_INTEGER_32) 0L))) {
		for (;;) {
			if ((EIF_BOOLEAN) (loc1 > ((EIF_INTEGER_32) 2L))) break;
			F1132_10009(RTCW(Result), (EIF_CHARACTER_8) '=');
			loc1++;
		}
	}
	RTLE;
	return Result;
}

/* {BASE64}.character_map */

EIF_REFERENCE F255_3621 (EIF_REFERENCE Current)
{
	GTCX
	RTOUC (723,RTMS_EX_H("ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=",65,980824637));
}

void EIF_Minit220 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C5/ba220.c <==
/*
 * Code for class BASE64
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ba220.h"
#include "eif_built_in.h"
#include "eif_misc.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {BASE64}.has_error */
EIF_BOOLEAN F255_3600 (EIF_REFERENCE Current)
{
	return *(EIF_BOOLEAN *)(Current+ _CHROFF_0_0_);
}


/* {BASE64}.encoded_string */
EIF_REFERENCE F255_3602 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_CHARACTER_8 tc1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTCFDT;
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,loc5);
	RTLR(2,arg1);
	RTLR(3,loc4);
	RTLR(4,Result);
	RTLIU(5);
	
	RTGC;
	*(EIF_BOOLEAN *)(Current+ _CHROFF_0_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	loc5 = RTOUCR(718,F255_3608, (Current));
	loc2 = *(EIF_INTEGER_32 *)(RTCW(arg1) + O8435[Dtype(arg1)-1130]);
	loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (((EIF_INTEGER_32) 8L) * loc2) % ((EIF_INTEGER_32) 6L));
	if ((EIF_BOOLEAN) (loc1 > ((EIF_INTEGER_32) 0L))) {
		{
			static EIF_TYPE_INDEX typarr0[] = {0xFF01,1209,1084,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
			loc4 = RTLNSP2(typres0.id,0,(EIF_INTEGER_32) ((EIF_INTEGER_32) (((EIF_INTEGER_32) 8L) * loc2) + (EIF_INTEGER_32) (((EIF_INTEGER_32) 6L) - loc1)),sizeof(EIF_BOOLEAN), EIF_TRUE);
		}
		F1210_10713(RTCW(loc4), (EIF_BOOLEAN) 0, (EIF_INTEGER_32) ((EIF_INTEGER_32) (((EIF_INTEGER_32) 8L) * loc2) + (EIF_INTEGER_32) (((EIF_INTEGER_32) 6L) - loc1)));
	} else {
		{
			static EIF_TYPE_INDEX typarr0[] = {0xFF01,1209,1084,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
			loc4 = RTLNSP2(typres0.id,0,(EIF_INTEGER_32) (((EIF_INTEGER_32) 8L) * loc2),sizeof(EIF_BOOLEAN), EIF_TRUE);
		}
		F1210_10713(RTCW(loc4), (EIF_BOOLEAN) 0, (EIF_INTEGER_32) (((EIF_INTEGER_32) 8L) * loc2));
	}
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	for (;;) {
		if ((EIF_BOOLEAN) (loc1 > (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 1L)))) break;
		tc1 = F1133_9982(RTCW(arg1), (EIF_INTEGER_32) (loc1 + ((EIF_INTEGER_32) 1L)));
		loc3 = (EIF_INTEGER_32) (tc1);
		tb1 = eif_bit_test(EIF_INTEGER_32,loc3,((EIF_INTEGER_32) 7L));
		/* INLINED CODE (SPECIAL.put) */
		*((EIF_BOOLEAN *)RTCW(loc4) + ((EIF_INTEGER_32) ((EIF_INTEGER_32) (((EIF_INTEGER_32) 8L) * loc1) + ((EIF_INTEGER_32) 0L)))) = tb1;
		/* END INLINED CODE */
		;
		tb1 = eif_bit_test(EIF_INTEGER_32,loc3,((EIF_INTEGER_32) 6L));
		/* INLINED CODE (SPECIAL.put) */
		*((EIF_BOOLEAN *)RTCW(loc4) + ((EIF_INTEGER_32) ((EIF_INTEGER_32) (((EIF_INTEGER_32) 8L) * loc1) + ((EIF_INTEGER_32) 1L)))) = tb1;
		/* END INLINED CODE */
		;
		tb1 = eif_bit_test(EIF_INTEGER_32,loc3,((EIF_INTEGER_32) 5L));
		/* INLINED CODE (SPECIAL.put) */
		*((EIF_BOOLEAN *)RTCW(loc4) + ((EIF_INTEGER_32) ((EIF_INTEGER_32) (((EIF_INTEGER_32) 8L) * loc1) + ((EIF_INTEGER_32) 2L)))) = tb1;
		/* END INLINED CODE */
		;
		tb1 = eif_bit_test(EIF_INTEGER_32,loc3,((EIF_INTEGER_32) 4L));
		/* INLINED CODE (SPECIAL.put) */
		*((EIF_BOOLEAN *)RTCW(loc4) + ((EIF_INTEGER_32) ((EIF_INTEGER_32) (((EIF_INTEGER_32) 8L) * loc1) + ((EIF_INTEGER_32) 3L)))) = tb1;
		/* END INLINED CODE */
		;
		tb1 = eif_bit_test(EIF_INTEGER_32,loc3,((EIF_INTEGER_32) 3L));
		/* INLINED CODE (SPECIAL.put) */
		*((EIF_BOOLEAN *)RTCW(loc4) + ((EIF_INTEGER_32) ((EIF_INTEGER_32) (((EIF_INTEGER_32) 8L) * loc1) + ((EIF_INTEGER_32) 4L)))) = tb1;
		/* END INLINED CODE */
		;
		tb1 = eif_bit_test(EIF_INTEGER_32,loc3,((EIF_INTEGER_32) 2L));
		/* INLINED CODE (SPECIAL.put) */
		*((EIF_BOOLEAN *)RTCW(loc4) + ((EIF_INTEGER_32) ((EIF_INTEGER_32) (((EIF_INTEGER_32) 8L) * loc1) + ((EIF_INTEGER_32) 5L)))) = tb1;
		/* END INLINED CODE */
		;
		tb1 = eif_bit_test(EIF_INTEGER_32,loc3,((EIF_INTEGER_32) 1L));
		/* INLINED CODE (SPECIAL.put) */
		*((EIF_BOOLEAN *)RTCW(loc4) + ((EIF_INTEGER_32) ((EIF_INTEGER_32) (((EIF_INTEGER_32) 8L) * loc1) + ((EIF_INTEGER_32) 6L)))) = tb1;
		/* END INLINED CODE */
		;
		tb1 = eif_bit_test(EIF_INTEGER_32,loc3,((EIF_INTEGER_32) 0L));
		/* INLINED CODE (SPECIAL.put) */
		*((EIF_BOOLEAN *)RTCW(loc4) + ((EIF_INTEGER_32) ((EIF_INTEGER_32) (((EIF_INTEGER_32) 8L) * loc1) + ((EIF_INTEGER_32) 7L)))) = tb1;
		/* END INLINED CODE */
		;
		loc1++;
	}
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	loc2 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (loc4);
	Result = RTLNS(eif_new_type(1132, 0x01).id, 1132, _OBJSIZ_1_1_0_3_0_0_0_0_);
	F1131_9906(RTCW(Result), (EIF_INTEGER_32) (loc2 / ((EIF_INTEGER_32) 6L)));
	for (;;) {
		if ((EIF_BOOLEAN) (loc1 > (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 1L)))) break;
		loc3 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
		/* INLINED CODE (SPECIAL.item) */
		tb2 = *((EIF_BOOLEAN *)RTCW(loc4) + ((EIF_INTEGER_32) (loc1 + ((EIF_INTEGER_32) 0L))));
		/* END INLINED CODE */
		tb1 = tb2;
		if (tb1) {
			loc3 += ((EIF_INTEGER_32) 32L);
		}
		/* INLINED CODE (SPECIAL.item) */
		tb2 = *((EIF_BOOLEAN *)RTCW(loc4) + ((EIF_INTEGER_32) (loc1 + ((EIF_INTEGER_32) 1L))));
		/* END INLINED CODE */
		tb1 = tb2;
		if (tb1) {
			loc3 += ((EIF_INTEGER_32) 16L);
		}
		/* INLINED CODE (SPECIAL.item) */
		tb2 = *((EIF_BOOLEAN *)RTCW(loc4) + ((EIF_INTEGER_32) (loc1 + ((EIF_INTEGER_32) 2L))));
		/* END INLINED CODE */
		tb1 = tb2;
		if (tb1) {
			loc3 += ((EIF_INTEGER_32) 8L);
		}
		/* INLINED CODE (SPECIAL.item) */
		tb2 = *((EIF_BOOLEAN *)RTCW(loc4) + ((EIF_INTEGER_32) (loc1 + ((EIF_INTEGER_32) 3L))));
		/* END INLINED CODE */
		tb1 = tb2;
		if (tb1) {
			loc3 += ((EIF_INTEGER_32) 4L);
		}
		/* INLINED CODE (SPECIAL.item) */
		tb2 = *((EIF_BOOLEAN *)RTCW(loc4) + ((EIF_INTEGER_32) (loc1 + ((EIF_INTEGER_32) 4L))));
		/* END INLINED CODE */
		tb1 = tb2;
		if (tb1) {
			loc3 += ((EIF_INTEGER_32) 2L);
		}
		/* INLINED CODE (SPECIAL.item) */
		tb2 = *((EIF_BOOLEAN *)RTCW(loc4) + ((EIF_INTEGER_32) (loc1 + ((EIF_INTEGER_32) 5L))));
		/* END INLINED CODE */
		tb1 = tb2;
		if (tb1) {
			loc3++;
		}
		tc1 = F1133_9982(RTCW(loc5), (EIF_INTEGER_32) (loc3 + ((EIF_INTEGER_32) 1L)));
		F1133_10032(RTCW(Result), tc1);
		loc1 += ((EIF_INTEGER_32) 6L);
	}
	loc1 = *(EIF_INTEGER_32 *)(RTCW(arg1) + O8435[Dtype(arg1)-1130]);
	loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc1 % ((EIF_INTEGER_32) 3L));
	if ((EIF_BOOLEAN) (loc1 > ((EIF_INTEGER_32) 0L))) {
		for (;;) {
			if ((EIF_BOOLEAN) (loc1 > ((EIF_INTEGER_32) 2L))) break;
			F1133_10032(RTCW(Result), (EIF_CHARACTER_8) '=');
			loc1++;
		}
	}
	RTLE;
	return Result;
}

/* {BASE64}.character_map */

EIF_REFERENCE F255_3608 (EIF_REFERENCE Current)
{
	GTCX
	RTOUC (718,RTMS_EX_H("ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=",65,980824637));
}

void EIF_Minit220 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
